@@ -17,4 +17,12 @@ class Finding:
     module: str
     category: Category
     requirements: str
-    tool: str
\ No newline at end of file
+    tool: str
+
+@dataclass
+class EngineCodeFinding(Finding):
+    analysis_url: str
+    analysis_code: str
+    label: str
+    application_business_value: str
+    defect_type: str
\ No newline at end of file
