@@ -76,6 +76,11 @@ class TrufflehogRun(ToolGateway):
         enable_custom_rules = config_tool[tool]["ENABLE_CUSTOM_RULES"]
         if enable_custom_rules:
             Utils().configurate_external_checks(tool, config_tool, secret_tool, secret_external_checks, path)
+        exclude_detectors = config_tool[tool]["EXCLUDE_DETECTORS"]
+        if exclude_detectors:
+            exclude_detectors = ",".join(exclude_detectors)
+        filter_entropy = config_tool[tool].get("FILTER_ENTROPY")
+
 
         with concurrent.futures.ThreadPoolExecutor(max_workers=config_tool[tool]["NUMBER_THREADS"]) as executor:
             results = executor.map(
@@ -87,7 +92,9 @@ class TrufflehogRun(ToolGateway):
                 [repository_name] * len(include_paths),
                 [enable_custom_rules] * len(include_paths),
                 [agent_os] * len(include_paths),
-                [folder_path] * len(include_paths)
+                [folder_path] * len(include_paths),
+                [exclude_detectors] * len(include_paths),
+                [filter_entropy] * len(include_paths)
             )
         findings, file_findings = self.create_file(self.decode_output(results), path, config_tool, tool)
         return  findings, file_findings
@@ -124,15 +131,24 @@ class TrufflehogRun(ToolGateway):
         repository_name,
         enable_custom_rules,
         agent_os,
-        folder_path
+        folder_path,
+        exclude_detectors,
+        filter_entropy
     ):
         path_folder = folder_path if folder_path is not None else f"{path}/{repository_name}"
         command = f"{trufflehog_command} filesystem {path_folder} --include-paths {include_path} --exclude-paths {exclude_path} --no-verification --no-update --json"
+        
         if enable_custom_rules:
             command = command.replace("--no-verification --no-update --json", f"--config {path}//rules//trufflehog//custom-rules.yaml --no-verification --no-update --json" if "Windows" in agent_os else
                                       f"--config {path}/rules/trufflehog/custom-rules.yaml --no-verification --no-update --json" if "Linux" or "Darwin" in agent_os else
-                                      "--no-verification --no-update --json")
+                                      "--no-verification --no-update --json")  
             
+        if exclude_detectors:
+            command = f"{command} --exclude-detectors {exclude_detectors}"
+            
+        if filter_entropy:
+            command = f"{command} --filter-entropy={filter_entropy}"
+
         result = subprocess.run(command, capture_output=True, shell=True, text=True, encoding='utf-8')
         return result.stdout.strip()
 
